<template>
  <div>
    <Echart
      :id="id"
      ref="barChart"
      :options="options"
      :height="height"
      :width="width"
      @click="mapClick"
    ></Echart>
  </div>
</template>

<script>
import Echart from "@/common/echart";

export default {
  name: "mapechart",
  props: {
    id: {
      type: String,
      default: "barChart"
    },
    width: {
      type: String,
      default: "100%"
    },
    height: {
      type: String,
      default: "100px"
    },
    cdata: {
      type: Array,
      default: () => []
    }
  },
  data() {
    return {
      options: {}
    };
  },
  components: {
    Echart
  },
  watch: {
    cdata: {
      handler(newData) {
        this.resetOption(newData);
      },
      immediate: true,
      deep: true
    }
  },
  methods: {
    mapClick(data) {
      this.$emit("click", data);
    },

    resetOption(newData) {
      let xData = newData.map(item => item.name);
      this.options = {
        tooltip: {
          trigger: "axis",
          axisPointer: {
            type: "shadow"
          }
        },
        legend: {
          show: true
        },
        grid: {
          left: "6%",
          top:'18%',
          right: "4%",
          bottom: "6%",
          containLabel: true
        },
        xAxis: {
          type: "category",
          data: xData,
          axisLabel: {
            interval: 0,
            color: "#07dbff"
            // formatter: function (value) {
            //   return value.split("").join("\n");
            // },
          },
          axisLine: {
            lineStyle: {
              color: "#07dbff"
            }
          }
        },
        yAxis: {
          type: "value",
          name:"单位：例",
          max: function(value) {return value.max + 20;},
          nameTextStyle:{
            color:'#206ed4'
          },
          axisLine: {
            show: true,
            lineStyle: {
              color: "#07dbff"
            }
          },
          axisLabel: {
            color: "#07dbff"
          },
          splitLine: {
            show: true,
            lineStyle: {
              color: ['rgba(7,219,255,0.5)'],
              type: "dashed"
            }
          }

          // max: function(value) {
          //   return value;
          // },
        },
        
        animationDurationUpdate: 1000,
        series: [
          {
            name: "捐献案例月度统计",
            type: "line",
            data: newData.map(item => item.value),
            universalTransition: true,
            smooth: false,
            itemStyle: {
              normal: {
                label: {
                  show: true, //开启显示
                  position: "top", //在上方显示
                  textStyle: {
                    //数值样式
                    color: "#fff",
                    fontSize:10
                  }
                }
              }
            },
            lineStyle:{
              color:'#07dbff',
            }
          },
          {
            name: "捐献器官月度统计",
            type: "line",
            //yAxisIndex: 1,
            data: newData.map(item => item.value2),
            universalTransition: true,
            smooth: false,
            itemStyle: {
              normal: {
                label: {
                  show: true, //开启显示
                  position: "top", //在上方显示
                  textStyle: {
                    //数值样式
                    color: "#fff",
                    fontSize:10
                  }
                }
              }
            },
          }
        ]
      };
    },
    // 开启定时器
    startInterval() {
      const _self = this;
      // 应通过接口获取配置时间，暂时写死5s
      const time = 2000;
      if (this.intervalId !== null) {
        clearInterval(this.intervalId);
      }
      this.intervalId = setInterval(() => {
        _self.reSelectMapRandomArea();
      }, time);
    },
    // 重新随机选中地图区域
    reSelectMapRandomArea() {
      const length = 9;
      this.$nextTick(() => {
        const map = this.$refs.mapChart.chart;
        let index = Math.floor(Math.random() * length);
        while (index === this.preSelectMapIndex || index >= length) {
          index = Math.floor(Math.random() * length);
        }
        map.dispatchAction({
          type: "mapUnSelect",
          seriesIndex: 0,
          dataIndex: this.preSelectMapIndex
        });
        map.dispatchAction({
          type: "showTip",
          seriesIndex: 0,
          dataIndex: index
        });
        map.dispatchAction({
          type: "mapSelect",
          seriesIndex: 0,
          dataIndex: index
        });
        this.preSelectMapIndex = index;
      });
    },
    handleMapRandomSelect() {
      this.$nextTick(() => {
        const map = this.$refs.mapChart.chart;
        const _self = this;
        setTimeout(() => {
          _self.reSelectMapRandomArea();
        }, 0);
        // 移入区域，清除定时器、取消之前选中并选中当前
        map.on("mouseover", function(params) {
          clearInterval(_self.intervalId);
          map.dispatchAction({
            type: "mapUnSelect",
            seriesIndex: 0,
            dataIndex: _self.preSelectMapIndex
          });
          map.dispatchAction({
            type: "mapSelect",
            seriesIndex: 0,
            dataIndex: params.dataIndex
          });
          _self.preSelectMapIndex = params.dataIndex;
        });
        // 移出区域重新随机选中地图区域，并开启定时器
        map.on("globalout", function() {
          _self.reSelectMapRandomArea();
          _self.startInterval();
        });
        this.startInterval();
      });
    }
  }
};
</script>
